@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2018 Laurent Montel <montel@kde.org>
+    Copyright (c) 2013-2019 Laurent Montel <montel@kde.org>
 
     Copyright (c) 2010 Volker Krause <vkrause@kde.org>
 
@@ -45,43 +45,11 @@ class NewMailNotifierAgent : public Akonadi::AgentBase, public Akonadi::AgentBas
 public:
     explicit NewMailNotifierAgent(const QString &id);
 
-    void showConfigureDialog(qlonglong windowId = 0);
-
     void setEnableAgent(bool b);
     bool enabledAgent() const;
 
-    void setVerboseMailNotification(bool b);
-    bool verboseMailNotification() const;
-
-    void setBeepOnNewMails(bool b);
-    bool beepOnNewMails() const;
-
-    void setShowPhoto(bool b);
-    bool showPhoto() const;
-
-    void setShowFrom(bool b);
-    bool showFrom() const;
-
-    void setShowSubject(bool b);
-    bool showSubject() const;
-
-    void setShowFolderName(bool b);
-    bool showFolderName() const;
-
-    void setExcludeMyselfFromNotification(bool b);
-    bool excludeMyselfFromNotification() const;
-
-    void setTextToSpeakEnabled(bool enabled);
-    bool textToSpeakEnabled() const;
-
-    QString textToSpeak() const;
-    void setTextToSpeak(const QString &msg);
-
     void printDebug();
 
-    bool showButtonToDisplayMail() const;
-    void setShowButtonToDisplayMail(bool b);
-
 protected:
     void itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection) override;
     void itemsMoved(const Akonadi::Item::List &items, const Akonadi::Collection &sourceCollection, const Akonadi::Collection &destinationCollection) override;
@@ -89,9 +57,6 @@ protected:
     void itemsFlagsChanged(const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags) override;
     void doSetOnline(bool online) override;
 
-private Q_SLOTS:
-    void configure(WId windowId) override;
-
 private:
     void slotShowNotifications();
     void slotInstanceStatusChanged(const Akonadi::AgentInstance &instance);
