@@ -97,7 +97,7 @@ QStringList SearchDialog::selection() const
     QStringList ret;
     ret.reserve(indexes.count());
     for (const QModelIndex &index : indexes) {
-        qCritical() << "SELECTED DATA: " << index.data(Qt::UserRole + 1).toString();
+        //qCritical() << "SELECTED DATA: " << index.data(Qt::UserRole + 1).toString();
         ret << index.data(Qt::UserRole + 1).toString();
     }
     return ret;
@@ -129,7 +129,7 @@ void SearchDialog::search()
     KDAV::DavUrl davUrl;
     davUrl.setUrl(url);
 
-    KDAV::DavPrincipalSearchJob *job = new KDAV::DavPrincipalSearchJob(davUrl, filter, mUi.searchParam->text());
+    KDAV::DavPrincipalSearchJob *job = new KDAV::DavPrincipalSearchJob(davUrl, filter, mUi.searchParam->text(), this);
 
     const KDAV::DavProtocolBase *proto = KDAV::DavManager::self()->davProtocol(KDAV::CalDav);
     job->fetchProperty(proto->principalHomeSet(), proto->principalHomeSetNS());
