@@ -24,9 +24,7 @@
 #include <KLocalizedString>
 
 #include "auth/ewspasswordauth.h"
-#ifdef HAVE_NETWORKAUTH
 #include "auth/ewsoauth.h"
-#endif
 
 #include "ewsresource_debug.h"
 
@@ -42,8 +40,13 @@ constexpr int walletTimeout = 30000;
 using namespace KWallet;
 
 EwsSettings::EwsSettings(WId windowId)
-    : EwsSettingsBase(), mWindowId(windowId), mPasswordReadPending(false), mPasswordWritePending(false),
-      mMapReadPending(false),  mMapWritePending(false), mWalletTimer(this)
+    : EwsSettingsBase()
+    , mWindowId(windowId)
+    , mPasswordReadPending(false)
+    , mPasswordWritePending(false)
+    , mMapReadPending(false)
+    , mMapWritePending(false)
+    , mWalletTimer(this)
 {
     mWalletTimer.setInterval(walletTimeout);
     mWalletTimer.setSingleShot(true);
@@ -104,7 +107,7 @@ void EwsSettings::requestPassword(bool ask)
             mPasswordDlg = new KPasswordDialog(nullptr);
             mPasswordDlg->setModal(true);
             mPasswordDlg->setPrompt(i18n("Please enter password for user '%1' and Exchange account '%2'.",
-                                username(), email()));
+                                         username(), email()));
             if (mPasswordDlg->exec() == QDialog::Accepted) {
                 mPassword = mPasswordDlg->password();
                 setPassword(mPassword);
@@ -316,13 +319,11 @@ EwsAbstractAuth *EwsSettings::loadAuth(QObject *parent)
 
     EwsAbstractAuth *auth = nullptr;
     const auto mode = authMode();
-#ifdef HAVE_NETWORKAUTH
     if (mode == QStringLiteral("oauth2")) {
         qCDebugNC(EWSRES_LOG) << QStringLiteral("Using OAuth2 authentication");
 
         auth = new EwsOAuth(parent, email(), oAuth2AppId(), oAuth2ReturnUri());
     }
-#endif
     if (mode == QStringLiteral("username-password")) {
         qCDebugNC(EWSRES_LOG) << QStringLiteral("Using password-based authentication");
 
@@ -350,4 +351,5 @@ EwsAbstractAuth *EwsSettings::loadAuth(QObject *parent)
 
     return auth;
 }
+
 #endif /* EWSSETTINGS_UNITTEST */
