@@ -37,8 +37,6 @@
 
 ChangeCollectionTask::ChangeCollectionTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
     : ResourceTask(DeferIfNoSession, resource, parent)
-    , m_pendingJobs(0)
-    , m_syncEnabledState(true)
 {
 }
 
