@@ -20,7 +20,7 @@
 
 #include <kcalcore/event.h>
 #include <kcalcore/todo.h>
-#include <qdebug.h>
+#include <QDebug>
 #include <kolabevent.h>
 #include <QDate>
 #include <QTimeZone>
