@@ -12,7 +12,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "event.h"
@@ -98,7 +98,7 @@ std::string Event::toICal() const
 
 bool Event::fromIMip(const std::string &input)
 {
-    std::vector<Kolab::Event> list = mITipHandler.fromIMip(input);
+    const std::vector<Kolab::Event> list = mITipHandler.fromIMip(input);
     if (list.size() != 1) {
         std::cout << "invalid number of events: " << list.size();
         return false;
