@@ -37,7 +37,7 @@
 
 #include <QSignalSpy>
 
-#include <qtest.h>
+#include <QTest>
 #include <QFileInfo>
 #include <QDir>
 
