@@ -99,7 +99,7 @@ void TomboyItemUploadJob::onRequestFinished()
         emitResult();
         return;
     }
-    qCDebug(TOMBOYNOTESRESOURCE_LOG) << "TomboyItemUploadJob: Network request finished. No error occured";
+    qCDebug(TOMBOYNOTESRESOURCE_LOG) << "TomboyItemUploadJob: Network request finished. No error occurred";
 
     // Parse received data as JSON
     const QJsonDocument document = QJsonDocument::fromJson(mReply->readAll(), nullptr);
@@ -138,7 +138,7 @@ QString TomboyItemUploadJob::getCurrentISOTime() const
     QDateTime utc = local.toUTC();
     utc.setTimeSpec(Qt::LocalTime);
     int utcOffset = utc.secsTo(local);
-    local.setUtcOffset(utcOffset);
+    local.setOffsetFromUtc(utcOffset);
 
     return local.toString(Qt::ISODate);
 }
